@@ -61,7 +61,7 @@ void TransitionParameters::initialize(const ModelMetadata& metadata)
         } else {
             initialize_sqkmap006_complement();
         }
-    } else if(metadata.kit == KV_SQK007) {
+    } else if(metadata.is_r9()) {
         if(metadata.strand_idx == T_IDX) {
             initialize_sqkmap007_template();
         } else {
@@ -301,7 +301,7 @@ void TransitionParameters::add_training_from_alignment(const HMMInputSequence& s
         return;
     }
 
-    const PoreModel& pm = data.read->pore_model[data.strand];
+    const PoreModel& pm = *data.pore_model;
     const uint32_t k = pm.k;
 
     size_t n_kmers = sequence.length() - k + 1;
@@ -344,8 +344,8 @@ void TransitionParameters::add_training_from_alignment(const HMMInputSequence& s
                 uint32_t rank_1 = sequence.get_kmer_rank(transition_kmer_from, k, data.rc);
                 uint32_t rank_2 = sequence.get_kmer_rank(transition_kmer_to, k, data.rc);
             
-                GaussianParameters level_1 = pm.get_scaled_parameters(rank_1);
-                GaussianParameters level_2 = pm.get_scaled_parameters(rank_2);
+                GaussianParameters level_1 = data.read->get_scaled_gaussian_from_pore_model_state(*data.pore_model, data.strand, rank_1);
+                GaussianParameters level_2 = data.read->get_scaled_gaussian_from_pore_model_state(*data.pore_model, data.strand, rank_2);
             
 #ifdef PRINT_TRAINING_MESSAGES
                 printf("TRAIN_SKIP\t%d\t%.3lf\t%.3lf\t%c\n", strand_idx, level_1.mean, level_2.mean, s);
